using UnityEngine;
#if UNITY_EDITOR
using UnityEditor;
#endif
using System.IO;
using UnityEditor.Callbacks;
using UnityEditor.iOS.Xcode;
using UnityEditor.iOS.Xcode.Extensions;

public class PostProcessApplovin : MonoBehaviour {
    const string applovinFrameworkName = "AppLovinSDK.xcframework";

    [PostProcessBuild(101)]
    private static void PostProcessBuild_Applovin(BuildTarget target, string buildPath)
    {
#if UNITY_EDITOR_OSX
        if (target == BuildTarget.iOS) {
            
            string projPath = PBXProject.GetPBXProjectPath(buildPath);
            PBXProject proj = new PBXProject();
            proj.ReadFromString(File.ReadAllText(projPath));
               
#if UNITY_2019_3_OR_NEWER

            Debug.Log ("Embedding Applovin frameworks into Unity-iPhone target...");
            string targetGuid = proj.GetUnityFrameworkTargetGuid();
            EmbedApplovinFramework(proj, projPath, targetGuid, applovinFrameworkName);
            
#else
            // Unity projects before 2019.3 do not contain runtime search paths needed for dynamic libraries.
            Debug.Log ("Adding the runtime search path to Unity-iPhone target...");
            string targetGuid = proj.TargetGuidByName("Unity-iPhone");
            proj.SetBuildProperty(targetGuid, "LD_RUNPATH_SEARCH_PATHS", "$(inherited) @executable_path/Frameworks");
#endif
            
            proj.WriteToFile (projPath);
        }
#endif
    }
    
    private static void EmbedApplovinFramework(PBXProject proj, string projPath, string targetGuid, string framework)
    {
#if UNITY_EDITOR_OSX
        string currentDirectory = Directory.GetCurrentDirectory();

        string filePath = FindFileInSubFolders(currentDirectory, applovinFrameworkName);
        string applovinFrameworkPath = filePath.Replace(currentDirectory + Path.DirectorySeparatorChar, string.Empty);
        string fileGuid = proj.AddFile(applovinFrameworkPath, applovinFrameworkPath, PBXSourceTree.Source);
        PBXProjectExtensions.AddFileToEmbedFrameworks(proj, targetGuid, fileGuid);

        //Add search paths
        proj.SetBuildProperty (targetGuid, "LD_RUNPATH_SEARCH_PATHS", "$(inherited) @executable_path/Frameworks @loader_path/Frameworks");
#endif
    }

    public static string FindFileInSubFolders(string currentDirectory, string fileName)
    {
        foreach (var directory in Directory.GetDirectories(currentDirectory))
        {
            var foundFiles = Directory.GetFiles(directory, fileName);
            if (foundFiles.Length > 0)
            {
                return foundFiles[0];
            }

            string foundInSubFolder = FindFileInSubFolders(directory, fileName);
            if (foundInSubFolder != null)
            {
                return foundInSubFolder;
            }
        }

        return null;
    }
}